@@ -18,8 +18,10 @@ import six
 
 from oslo_utils.timeutils import parse_isotime
 
+from barbicanclient import acls as acl_manager
 from barbicanclient import base
 from barbicanclient import formatter
+
 from barbicanclient import secrets as secret_manager
 
 
@@ -92,6 +94,8 @@ class Container(ContainerFormatter):
             self._created = None
             self._updated = None
             self._status = None
+        self._acl_manager = acl_manager.ACLManager(api)
+        self._acls = None
 
     def _initialize_secrets(self, secrets):
         try:
@@ -138,6 +142,13 @@ class Container(ContainerFormatter):
             self._reload()
         return self._status
 
+    @property
+    def acls(self):
+        """Get ACL settings for this container."""
+        if self._container_ref and not self._acls:
+            self._acls = self._acl_manager.get(self.container_ref)
+        return self._acls
+
     @property
     def secret_refs(self):
         if self._cached_secrets:
@@ -210,7 +221,8 @@ class Container(ContainerFormatter):
 
     def _get_secrets_and_store_them_if_necessary(self):
         # Save all secrets if they are not yet saved
-        LOG.debug("Storing secrets: {0}".format(self.secrets))
+        LOG.debug("Storing secrets: {0}".format(base.censored_copy(
+                                                self.secrets, ['payload'])))
         secret_refs = []
         for name, secret in six.iteritems(self.secrets):
             if secret and not secret.secret_ref:
@@ -707,14 +719,13 @@ class ContainerManager(base.BaseEntityManager):
         """
         LOG.debug('Listing containers - offset {0} limit {1} name {2} type {3}'
                   .format(offset, limit, name, type))
-        href = '{0}/{1}'.format(self._api._base_url, self._entity)
         params = {'limit': limit, 'offset': offset}
         if name:
             params['name'] = name
         if type:
             params['type'] = type
 
-        response = self._api.get(href, params=params)
+        response = self._api.get(self._entity, params=params)
 
         return [self._generate_typed_container(container)
                 for container in response.get('containers', [])]
@@ -755,9 +766,8 @@ class ContainerManager(base.BaseEntityManager):
         """
         LOG.debug('Deleting consumer registration for container '
                   '{0} as {1}: {2}'.format(container_ref, name, url))
-        href = '{0}/{1}/{2}/consumers'.format(self._api._base_url,
-                                              self._entity,
-                                              container_ref.split('/')[-1])
+        href = '{0}/{1}/consumers'.format(self._entity,
+                                          container_ref.split('/')[-1])
         consumer_dict = {
             'name': name,
             'URL': url
