@@ -16,12 +16,13 @@
 import base64
 import sys
 
+from barbicanclient import exceptions
 from functionaltests.client import base
-from functionaltests.client.v1.behaviors import secret_behaviors
+from functionaltests.common import cleanup
+from functionaltests.common import keys
 from functionaltests import utils
 from testtools import testcase
 
-from barbicanclient import exceptions
 
 secret_create_defaults_data = {
     "name": "AES key",
@@ -60,22 +61,22 @@ class SecretsTestCase(base.TestCase):
 
     def setUp(self):
         super(SecretsTestCase, self).setUp()
-        self.behaviors = secret_behaviors.SecretBehaviors(self.barbicanclient)
+        self.cleanup = cleanup.CleanUp(self.barbicanclient)
 
     def tearDown(self):
-        self.behaviors.delete_all_created_secrets()
+        self.cleanup.delete_all_entities()
         super(SecretsTestCase, self).tearDown()
 
     @testcase.attr('positive')
     def test_secret_create_defaults_check_content_types(self):
         """Check that set content-type attribute is retained in metadata."""
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
 
-        secret_ref = self.behaviors.store_secret(test_model)
+        secret_ref = self.cleanup.add_entity(secret)
         self.assertIsNotNone(secret_ref)
 
-        resp = self.behaviors.get_secret(secret_ref)
+        resp = self.barbicanclient.secrets.get(secret_ref)
         content_types = resp.content_types
         self.assertIsNotNone(content_types)
         self.assertIn('default', content_types)
@@ -87,15 +88,32 @@ class SecretsTestCase(base.TestCase):
 
          Currently the client will accept any string for the algorithm.
          """
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.algorithm = "not-an-algorithm"
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.algorithm = "not-an-algorithm"
 
-        secret_ref = self.behaviors.store_secret(test_model)
+        secret_ref = self.cleanup.add_entity(secret)
         self.assertIsNotNone(secret_ref)
 
-        get_resp = self.behaviors.get_secret(secret_ref)
-        self.assertEqual(get_resp.algorithm, test_model.algorithm)
+        resp = self.barbicanclient.secrets.get(secret_ref)
+        self.assertEqual(secret.algorithm, resp.algorithm)
+
+    @testcase.attr('positive')
+    def test_secret_read_with_acls(self):
+        """Access default ACL settings data on recently created secret.
+
+        By default, 'read' ACL settings are there for a secret.
+         """
+        test_model = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+
+        secret_ref = self.cleanup.add_entity(test_model)
+        self.assertIsNotNone(secret_ref)
+
+        secret_entity = self.barbicanclient.secrets.get(secret_ref)
+        self.assertIsNotNone(secret_entity.acls)
+        self.assertIsNotNone(secret_entity.acls.read)
+        self.assertEqual([], secret_entity.acls.read.users)
 
     @testcase.attr('positive')
     def test_secret_create_defaults_non_standard_mode(self):
@@ -103,15 +121,15 @@ class SecretsTestCase(base.TestCase):
 
         Currently the client will accept any string for the mode.
         """
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.mode = 'not-a-mode'
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.mode = 'not-a-mode'
 
-        secret_ref = self.behaviors.store_secret(test_model)
+        secret_ref = self.cleanup.add_entity(secret)
         self.assertIsNotNone(secret_ref)
 
-        get_resp = self.behaviors.get_secret(secret_ref)
-        self.assertEqual(get_resp.mode, test_model.mode)
+        resp = self.barbicanclient.secrets.get(secret_ref)
+        self.assertEqual(secret.mode, resp.mode)
 
     @testcase.attr('negative')
     def test_secret_delete_doesnt_exist(self):
@@ -119,12 +137,13 @@ class SecretsTestCase(base.TestCase):
 
         This delete uses a reference with an invalid UUID format
         """
-        url = self.behaviors.base_url + '/secrets/notauuid'
+        url = self.barbicanclient.secrets._api.endpoint_override + \
+            '/secrets/notauuid'
 
-        e = self.assertRaises(ValueError, self.behaviors.delete_secret,
+        e = self.assertRaises(ValueError, self.barbicanclient.secrets.delete,
                               url)
 
-        self.assertEqual(e.message, 'Secret incorrectly specified.')
+        self.assertEqual('Secret incorrectly specified.', e.message)
 
     @testcase.attr('negative')
     def test_secret_delete_doesnt_exist_valid_uuid_format(self):
@@ -134,47 +153,16 @@ class SecretsTestCase(base.TestCase):
         associated with this UUID
         """
         uuid = 'de20ad54-85b4-421b-adb2-eb7b9e546013'
-        url = self.behaviors.base_url + '/secrets/' + uuid
+        url = self.barbicanclient.secrets._api.endpoint_override + \
+            '/secrets/' + uuid
 
         e = self.assertRaises(
             exceptions.HTTPClientError,
-            self.behaviors.delete_secret,
+            self.barbicanclient.secrets.delete,
             url
         )
 
-        self.assertEqual(e.status_code, 404)
-
-    @testcase.attr('negative')
-    def test_secret_create_nones_content_type(self):
-        """Create secret with valid content type but no payload.
-
-        Secret will not create due to None in the payload even if content
-        type is valid.
-        """
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.payload = None
-
-        self.assertRaises(
-            exceptions.PayloadException,
-            self.behaviors.store_secret,
-            test_model
-        )
-
-    @testcase.attr('negative')
-    def test_secret_create_nones(self):
-        """Cover case of posting with all nones in the Secret object."""
-        test_model = self.behaviors.create_secret(
-            secret_create_nones_data)
-        test_model.payload = None
-        test_model.payload_content_encoding = None
-        test_model.payload_content_type = None
-
-        self.assertRaises(
-            exceptions.PayloadException,
-            self.behaviors.store_secret,
-            test_model
-        )
+        self.assertEqual(404, e.status_code)
 
     @testcase.attr('negative')
     def test_secret_get_secret_doesnt_exist(self):
@@ -183,10 +171,11 @@ class SecretsTestCase(base.TestCase):
         Will get value error secret incorrectly specified since "notauuid"
         is not a properly formatted uuid.
         """
-        url = self.behaviors.base_url + '/secrets/notauuid'
+        url = self.barbicanclient.secrets._api.endpoint_override + \
+            '/secrets/notauuid'
 
-        e = self.assertRaises(ValueError, self.behaviors.get_secret,
-                              url)
+        e = self.assertRaises(ValueError, self.barbicanclient.secrets.get,
+                              url, 'text/plain')
 
         self.assertIn("Secret incorrectly specified", e.message)
 
@@ -196,16 +185,15 @@ class SecretsTestCase(base.TestCase):
 
         Returns a 400.
         """
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.expiration = '2000-01-10T14:58:52.546795'
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.expiration = '2000-01-10T14:58:52.546795'
 
         e = self.assertRaises(
             exceptions.HTTPClientError,
-            self.behaviors.store_secret,
-            test_model
+            secret.store
         )
-        self.assertEqual(e.status_code, 400)
+        self.assertEqual(400, e.status_code)
 
     @testcase.attr('negative')
     def test_secret_create_emptystrings(self):
@@ -213,13 +201,12 @@ class SecretsTestCase(base.TestCase):
 
         Fails with a value error, Payload incorrectly specified.
         """
-        test_model = self.behaviors.create_secret(
-            secret_create_emptystrings_data)
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_emptystrings_data)
 
         self.assertRaises(
             exceptions.PayloadException,
-            self.behaviors.store_secret,
-            test_model
+            secret.store
         )
 
     @testcase.attr('negative')
@@ -229,16 +216,15 @@ class SecretsTestCase(base.TestCase):
         Should return a 413 if the secret size is greater than the
         maximum allowed size.
         """
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.payload = str(self.oversized_payload)
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.payload = str(self.oversized_payload)
 
         e = self.assertRaises(
             exceptions.HTTPClientError,
-            self.behaviors.store_secret,
-            test_model
+            secret.store
         )
-        self.assertEqual(e.status_code, 413)
+        self.assertEqual(413, e.status_code)
 
     @utils.parameterized_dataset({
         'alphanumeric': ['1f34ds'],
@@ -251,15 +237,15 @@ class SecretsTestCase(base.TestCase):
     @testcase.attr('positive')
     def test_secret_create_defaults_valid_name(self, name):
         """Covers cases of creating secrets with valid names."""
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.name = name
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.name = name
 
-        secret_ref = self.behaviors.store_secret(test_model)
+        secret_ref = self.cleanup.add_entity(secret)
         self.assertIsNotNone(secret_ref)
 
-        get_resp = self.behaviors.get_secret(secret_ref)
-        self.assertEqual(get_resp.name, test_model.name)
+        resp = self.barbicanclient.secrets.get(secret_ref)
+        self.assertEqual(secret.name, resp.name)
 
     @utils.parameterized_dataset({
         'int': [400]
@@ -270,17 +256,16 @@ class SecretsTestCase(base.TestCase):
 
         Should return 400.
         """
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.name = name
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.name = name
 
         e = self.assertRaises(
             exceptions.HTTPClientError,
-            self.behaviors.store_secret,
-            test_model
+            secret.store
         )
 
-        self.assertEqual(e.status_code, 400)
+        self.assertEqual(400, e.status_code)
 
     @utils.parameterized_dataset({
         'aes': ['aes']
@@ -288,15 +273,15 @@ class SecretsTestCase(base.TestCase):
     @testcase.attr('positive')
     def test_secret_create_defaults_valid_algorithms(self, algorithm):
         """Creates secrets with various valid algorithms."""
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.algorithm = algorithm
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.algorithm = algorithm
 
-        secret_ref = self.behaviors.store_secret(test_model)
+        secret_ref = self.cleanup.add_entity(secret)
         self.assertIsNotNone(secret_ref)
 
-        get_resp = self.behaviors.get_secret(secret_ref)
-        self.assertEqual(get_resp.algorithm, test_model.algorithm)
+        resp = self.barbicanclient.secrets.get(secret_ref)
+        self.assertEqual(secret.algorithm, resp.algorithm)
 
     @utils.parameterized_dataset({
         'int': [400]
@@ -305,19 +290,77 @@ class SecretsTestCase(base.TestCase):
     def test_secret_create_defaults_invalid_algorithms(self, algorithm):
         """Creates secrets with various invalid algorithms."""
 
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.algorithm = algorithm
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.algorithm = algorithm
 
         # We are currently testing for exception with http_code
         # launchpad bug 1431514 will address the change to this functionality
         e = self.assertRaises(
             exceptions.HTTPClientError,
-            self.behaviors.store_secret,
-            test_model
+            secret.store
         )
 
-        self.assertEqual(e.status_code, 400)
+        self.assertEqual(400, e.status_code)
+
+    @utils.parameterized_dataset({
+        'symmetric': ['symmetric',
+                      'aes',
+                      128,
+                      ('\x00\x01\x02\x03\x04\x05\x06\x07'
+                       '\x00\x01\x02\x03\x04\x05\x06\x07')],
+        'private': ['private',
+                    'rsa',
+                    2048,
+                    keys.get_private_key_pem()],
+        'public': ['public',
+                   'rsa',
+                   2048,
+                   keys.get_public_key_pem()],
+        'certificate': ['certificate',
+                        'rsa',
+                        2048,
+                        keys.get_certificate_pem()],
+        'opaque': ['opaque',
+                   None,
+                   None,
+                   (b'\x00\x01\x02\x03\x04\x05\x06\x07')],
+        'passphrase': ['passphrase',
+                       None,
+                       None,
+                       keys.get_passphrase_txt()],
+    })
+    @testcase.attr('positive')
+    def test_secret_create_defaults_valid_secret_type(
+            self, secret_type, algorithm, bit_length, payload):
+        """Covers cases of creating secrets with valid secret types."""
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.secret_type = secret_type
+        secret.algorithm = algorithm
+        secret.bit_length = bit_length
+        # payload should not be encoded.
+        secret.payload = payload
+
+        secret_ref = self.cleanup.add_entity(secret)
+        self.assertIsNotNone(secret_ref)
+
+        resp = self.barbicanclient.secrets.get(secret_ref)
+        self.assertEqual(secret_type, resp.secret_type)
+
+    @testcase.attr('negative')
+    def test_secret_create_defaults_invalid_secret_type(self):
+        """Covers cases of creating secrets with invalid secret types."""
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.secret_type = 'not a valid secret type'
+
+        e = self.assertRaises(
+            exceptions.HTTPClientError,
+            secret.store
+        )
+
+        self.assertEqual(400, e.status_code)
 
     @utils.parameterized_dataset({
         '512': [512],
@@ -331,15 +374,15 @@ class SecretsTestCase(base.TestCase):
     @testcase.attr('positive')
     def test_secret_create_defaults_valid_bit_length(self, bit_length):
         """Covers cases of creating secrets with valid bit lengths."""
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.bit_length = bit_length
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.bit_length = bit_length
 
-        secret_ref = self.behaviors.store_secret(test_model)
+        secret_ref = self.cleanup.add_entity(secret)
         self.assertIsNotNone(secret_ref)
 
-        get_resp = self.behaviors.get_secret(secret_ref)
-        self.assertEqual(get_resp.bit_length, test_model.bit_length)
+        resp = self.barbicanclient.secrets.get(secret_ref)
+        self.assertEqual(secret.bit_length, resp.bit_length)
 
     @utils.parameterized_dataset({
         'str_type': ['not-an-int'],
@@ -352,17 +395,16 @@ class SecretsTestCase(base.TestCase):
     @testcase.attr('negative')
     def test_secret_create_defaults_invalid_bit_length(self, bit_length):
         """Covers cases of creating secrets with invalid bit lengths."""
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.bit_length = bit_length
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.bit_length = bit_length
 
         e = self.assertRaises(
             exceptions.HTTPClientError,
-            self.behaviors.store_secret,
-            test_model
+            secret.store
         )
 
-        self.assertEqual(e.status_code, 400)
+        self.assertEqual(400, e.status_code)
 
     @utils.parameterized_dataset({
         'cbc': ['cbc']
@@ -370,15 +412,15 @@ class SecretsTestCase(base.TestCase):
     @testcase.attr('positive')
     def test_secret_create_defaults_valid_mode(self, mode):
         """Covers cases of creating secrets with valid modes."""
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.mode = mode
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.mode = mode
 
-        secret_ref = self.behaviors.store_secret(test_model)
+        secret_ref = self.cleanup.add_entity(secret)
         self.assertIsNotNone(secret_ref)
 
-        get_resp = self.behaviors.get_secret(secret_ref)
-        self.assertEqual(get_resp.mode, test_model.mode)
+        resp = self.barbicanclient.secrets.get(secret_ref)
+        self.assertEqual(secret.mode, resp.mode)
 
     @utils.parameterized_dataset({
         'zero': [0],
@@ -388,17 +430,16 @@ class SecretsTestCase(base.TestCase):
     @testcase.attr('negative')
     def test_secret_create_defaults_invalid_mode(self, mode):
         """Covers cases of creating secrets with invalid modes."""
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.mode = mode
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.mode = mode
 
         e = self.assertRaises(
             exceptions.HTTPClientError,
-            self.behaviors.store_secret,
-            test_model
+            secret.store
         )
 
-        self.assertEqual(e.status_code, 400)
+        self.assertEqual(400, e.status_code)
 
     @utils.parameterized_dataset({
         'text_content_type_none_encoding': {
@@ -423,23 +464,22 @@ class SecretsTestCase(base.TestCase):
             payload_content_type,
             payload_content_encoding):
         """Creates secrets with various content types and encodings."""
-        test_model = self.behaviors.create_secret(secret_create_defaults_data)
-        test_model.payload_content_encoding = payload_content_encoding
-        test_model.payload_content_type = payload_content_type
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.payload_content_type = payload_content_type
+        secret.payload_content_encoding = payload_content_encoding
 
-        secret_ref = self.behaviors.store_secret(test_model)
+        secret_ref = self.cleanup.add_entity(secret)
         self.assertIsNotNone(secret_ref)
 
-        get_resp = self.behaviors.get_secret(
-            secret_ref,
-            payload_content_type=test_model.payload_content_type)
-        if test_model.payload_content_encoding == 'base64':
+        resp = self.barbicanclient.secrets.get(secret_ref)
+        if secret.payload_content_encoding == 'base64':
             self.assertEqual(
-                base64.b64decode(test_model.payload),
-                get_resp.payload
+                base64.b64decode(secret.payload),
+                resp.payload
             )
         else:
-            self.assertEqual(test_model.payload, str(get_resp.payload))
+            self.assertEqual(secret.payload, str(resp.payload))
 
     @utils.parameterized_dataset({
         'large_string_content_type_and_encoding': {
@@ -505,20 +545,19 @@ class SecretsTestCase(base.TestCase):
     @testcase.attr('negative')
     def test_secret_create_defaults_invalid_types_and_encoding(self, **kwargs):
         """Creating secrets with invalid payload types and encodings."""
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.payload_content_encoding = kwargs[
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.payload_content_encoding = kwargs[
             'payload_content_encoding']
-        test_model.payload_content_type = kwargs[
+        secret.payload_content_type = kwargs[
             'payload_content_type']
 
         e = self.assertRaises(
             exceptions.HTTPClientError,
-            self.behaviors.store_secret,
-            test_model
+            secret.store
         )
 
-        self.assertEqual(e.status_code, 400)
+        self.assertEqual(400, e.status_code)
 
     @utils.parameterized_dataset({
         'max_payload_string': [base.TestCase.max_sized_payload]
@@ -527,14 +566,15 @@ class SecretsTestCase(base.TestCase):
     def test_secret_create_defaults_valid_payload(self, payload):
         """Create secrets with a various valid payloads."""
 
-        test_model = self.behaviors.create_secret(secret_create_defaults_data)
-        test_model.payload = payload
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.payload = payload
 
-        secret_ref = self.behaviors.store_secret(test_model)
+        secret_ref = self.cleanup.add_entity(secret)
         self.assertIsNotNone(secret_ref)
 
-        get_resp = self.behaviors.get_secret(secret_ref)
-        self.assertEqual(test_model.payload, get_resp.payload)
+        resp = self.barbicanclient.secrets.get(secret_ref)
+        self.assertEqual(secret.payload, resp.payload)
 
     @utils.parameterized_dataset({
         'list': [['boom']],
@@ -546,19 +586,17 @@ class SecretsTestCase(base.TestCase):
 
         Tests the negative cases of invalid types (list and int).
         """
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.payload = payload
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.payload = payload
 
         self.assertRaises(
             exceptions.PayloadException,
-            self.behaviors.store_secret,
-            test_model
+            secret.store
         )
 
     @utils.parameterized_dataset({
         'empty': [''],
-        'none': [None],
         'zero': [0]
     })
     @testcase.attr('negative')
@@ -567,14 +605,13 @@ class SecretsTestCase(base.TestCase):
 
         These requests will fail with a value error before the request to the
         server is made"""
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.payload = payload
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.payload = payload
 
         self.assertRaises(
             exceptions.PayloadException,
-            self.behaviors.store_secret,
-            test_model
+            secret.store
         )
 
     @utils.parameterized_dataset({
@@ -599,16 +636,16 @@ class SecretsTestCase(base.TestCase):
         """Create secrets with a various valid expiration data."""
 
         timestamp = utils.create_timestamp_w_tz_and_offset(**kwargs)
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.expiration = timestamp
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.expiration = timestamp
 
-        secret_ref = self.behaviors.store_secret(test_model)
+        secret_ref = self.cleanup.add_entity(secret)
         self.assertIsNotNone(secret_ref)
 
-        get_resp = self.behaviors.get_secret(secret_ref)
-        self.assertIsNotNone(get_resp)
-        self.assertEqual(get_resp.name, test_model.name)
+        resp = self.barbicanclient.secrets.get(secret_ref)
+        self.assertIsNotNone(resp)
+        self.assertEqual(secret.name, resp.name)
 
     @utils.parameterized_dataset({
         'malformed_timezone': {
@@ -619,17 +656,45 @@ class SecretsTestCase(base.TestCase):
     def test_secret_create_defaults_invalid_expiration(self, **kwargs):
         """Create secrets with various invalid expiration data."""
         timestamp = utils.create_timestamp_w_tz_and_offset(**kwargs)
-        test_model = self.behaviors.create_secret(
-            secret_create_defaults_data)
-        test_model.expiration = timestamp
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.expiration = timestamp
 
         e = self.assertRaises(
             exceptions.HTTPClientError,
-            self.behaviors.store_secret,
-            test_model
+            secret.store
         )
 
-        self.assertEqual(e.status_code, 400)
+        self.assertEqual(400, e.status_code)
+
+    @utils.parameterized_dataset({
+        'text/plain':
+            [
+                u'meowwwwwwwmeowwwwwww',
+                'text/plain'],
+        'application/octet-stream':
+            [
+                base64.b64encode(
+                    b'F\x130\x89f\x8e\xd9\xa1\x0e\x1f\r\xf67uu\x8b'),
+                'application/octet-stream'
+            ]
+    })
+    @testcase.attr('positive')
+    def test_secret_update_nones(self, payload, payload_content_type):
+        """Cover case of updating with all nones in the Secret object."""
+        secret = self.barbicanclient.secrets.create(**secret_create_nones_data)
+        secret.payload = None
+        secret.payload_content_type = None
+
+        secret_ref = self.cleanup.add_entity(secret)
+        self.assertIsNotNone(secret_ref)
+
+        secret.payload = payload
+        secret.update()
+
+        resp = self.barbicanclient.secrets.get(secret_ref)
+        self.assertEqual(payload, resp.payload)
+        self.assertEqual(payload_content_type, resp.payload_content_type)
 
     @utils.parameterized_dataset({
         'alphanumeric': ['1f34ds'],
@@ -642,15 +707,62 @@ class SecretsTestCase(base.TestCase):
     @testcase.attr('positive')
     def test_secret_get_defaults_metadata_w_valid_name(self, name):
         """Covers getting and checking a secret's metadata."""
-        test_model = self.behaviors.create_secret(secret_create_defaults_data)
-        test_model.name = name
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.name = name
 
-        secret_ref = self.behaviors.store_secret(test_model)
+        secret_ref = self.cleanup.add_entity(secret)
         self.assertIsNotNone(secret_ref)
 
-        get_resp = self.behaviors.get_secret(secret_ref)
-        self.assertEqual(get_resp.status, "ACTIVE")
-        self.assertEqual(get_resp.name, name)
-        self.assertEqual(get_resp.mode, test_model.mode)
-        self.assertEqual(get_resp.algorithm, test_model.algorithm)
-        self.assertEqual(get_resp.bit_length, test_model.bit_length)
+        resp = self.barbicanclient.secrets.get(secret_ref)
+        self.assertEqual("ACTIVE", resp.status)
+        self.assertEqual(name, resp.name)
+        self.assertEqual(secret.mode, resp.mode)
+        self.assertEqual(secret.algorithm, resp.algorithm)
+        self.assertEqual(secret.bit_length, resp.bit_length)
+
+    @utils.parameterized_dataset({
+        'symmetric': ['symmetric',
+                      'aes',
+                      128,
+                      ('\x00\x01\x02\x03\x04\x05\x06\x07'
+                       '\x00\x01\x02\x03\x04\x05\x06\x07')],
+        'private': ['private',
+                    'rsa',
+                    2048,
+                    keys.get_private_key_pem()],
+        'public': ['public',
+                   'rsa',
+                   2048,
+                   keys.get_public_key_pem()],
+        'certificate': ['certificate',
+                        'rsa',
+                        2048,
+                        keys.get_certificate_pem()],
+        'opaque': ['opaque',
+                   None,
+                   None,
+                   (b'\x00\x01\x02\x03\x04\x05\x06\x07')],
+        'passphrase': ['passphrase',
+                       None,
+                       None,
+                       keys.get_passphrase_txt()],
+    })
+    @testcase.attr('positive')
+    def test_secret_get_defaults_secret_type(self, secret_type, algorithm,
+                                             bit_length, payload):
+        """Covers getting and checking a secret's metadata."""
+        secret = self.barbicanclient.secrets.create(
+            **secret_create_defaults_data)
+        secret.secret_type = secret_type
+        secret.algorithm = algorithm
+        secret.bit_length = bit_length
+        # payload should not be encoded.
+        secret.payload = payload
+
+        secret_ref = self.cleanup.add_entity(secret)
+        self.assertIsNotNone(secret_ref)
+
+        resp = self.barbicanclient.secrets.get(secret_ref)
+        self.assertEqual("ACTIVE", resp.status)
+        self.assertEqual(secret_type, resp.secret_type)
